import { defHttp } from '/@/utils/http/axios';
import { useGlobSetting } from '/@/hooks/setting';
const globSetting = useGlobSetting();
const baseUploadUrl = globSetting.uploadUrl;
enum Api {
  positionList = '/sys/position/list',
  userList = '/sys/user/list',
  roleList = '/sys/role/list',
  queryDepartTreeSync = '/sys/sysDepart/queryDepartTreeSync',
  queryTreeList = '/sys/sysDepart/queryTreeList',
  loadTreeData = '/sys/category/loadTreeData',
  loadDictItem = '/sys/category/loadDictItem/',
  getDictItems = '/sys/dict/getDictItems/',
  getTableList = '/sys/user/queryUserComponentData',
  getCategoryData = '/sys/category/loadAllData',
}

/**
 * 上传父路径
 */
export const uploadUrl=`${baseUploadUrl}/sys/common/upload`;

/**
 * 职务列表
 * @param params
 */
export const getPositionList = (params) => {
  return defHttp.get({ url: Api.positionList, params });
};

/**
 * 用户列表
 * @param params
 */
export const getUserList = (params) => {
  return defHttp.get({ url: Api.userList, params });
};

/**
 * 角色列表
 * @param params
 */
export const getRoleList = (params) => {
  return defHttp.get({ url: Api.roleList, params });
};

/**
 * 异步获取部门树列表
 */
export const queryDepartTreeSync = (params?) =>{
  return defHttp.get({ url: Api.queryDepartTreeSync, params });
}
/**
 * 获取部门树列表
 */
export const queryTreeList = (params?) =>{
  return defHttp.get({ url: Api.queryTreeList, params });
}

/**
 * 分类字典树控件 加载节点
 */
export const loadTreeData = (params?) =>{
  return defHttp.get({ url: Api.loadTreeData, params });
}


/**
 * 根据字典code加载字典text
 */
export const loadDictItem = (params?) =>{
  return defHttp.get({ url: Api.loadDictItem, params });
}

/**
 * 根据字典code加载字典text
 */
export const getDictItems = (dictCode) =>{
  return defHttp.get({ url: Api.getDictItems+dictCode},{joinTime:false});
}
/**
 * 部门用户modal选择列表加载list
 */
export const getTableList = (params)=>{
    return defHttp.get({url:Api.getTableList,params})
}
/**
 * 加载全部分类字典数据
 */
export const loadCategoryData = (params)=>{
    return defHttp.get({url:Api.getCategoryData,params})
}
/**
 * 文件上传
 */
export const uploadFile = (params,success)=>{
    return defHttp.uploadFile({url:uploadUrl}, params,{success})
}
